@@ -1,7 +1,16 @@
 from keyring import get_password
 from mongoengine import *
+from enum import Enum
 
-OPERATIONS = ('Added', 'Modified', 'Deleted')
+
+class OPERATIONS(Enum):
+    ADDED  = 1
+    MODIFIED = 2
+    REMOVED = 3
+
+    @classmethod
+    def choices(cls):
+        return tuple((i.name, i.value) for i in cls)
 
 
 class user_settings(Document):
@@ -37,7 +46,7 @@ class user_transaction(Document):
     source = StringField()
     currency = StringField()
     source_id = ObjectIdField()
-    operation = StringField(choices=OPERATIONS)
+    operation = StringField(choices=OPERATIONS.choices())
 
 
 class user_channel(Document):
